@@ -884,7 +884,7 @@ _gtk_accel_label_class_get_accelerator_label (GtkAccelLabelClass *klass,
         g_string_append (gstring, klass->mod_separator);
 
       if (accelerator_key >= GDK_KEY_KP_Space &&
-          accelerator_key <= GDK_KEY_KP_Equal)
+          accelerator_key <= GDK_KEY_KP_9)
         {
           /* Translators: "KP" means "numeric key pad". This string will
            * be used in accelerators such as "Ctrl+Shift+KP 1" in menus,
